var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import chalk from 'chalk';
import inquirer from 'inquirer';
import minimist from 'minimist';
import { createAppQuestions, createPluginQuestions } from './constants/questions.js';
import { create } from './utils/create.js';
import { getPackageInfo } from './utils/index.js';
class CookieCli {
    constructor(appName) {
        this.appName = appName;
    }
    run() {
        this.parseArgs();
    }
    parseArgs() {
        const argvs = minimist(process.argv.slice(2), {
            alias: {
                version: ['v'],
                help: ['h'],
                create: ['c'],
                plugin: ['p'] // 增加插件
            },
            boolean: ['version', 'help']
        });
        const _ = argvs._;
        const command = _[0];
        const appName = _[1];
        this.appName = appName;
        if (command) {
            switch (command) {
                case 'create': {
                    this.getAppOptions();
                    break;
                }
                case 'plugin': {
                    this.getPluginOptions();
                    break;
                }
            }
        }
        else {
            if (argvs.help) {
                console.log('Usage: cookie <command> [options]');
                console.log();
                console.log('Options:');
                console.log('  -v, --version       output the version number');
                console.log('  -h, --help          output usage information');
                console.log('  -c, --create        create react or vue app');
                console.log('  -p, --plugin        create plugin like eslint and so on..');
            }
            else if (argvs.version) {
                const version = getPackageInfo().version;
                console.log(chalk.blue('current cookie-cli version is ' + version));
            }
            else {
                console.log(chalk.yellow('Please input cookie -h for more commands'));
                process.exit(1);
            }
        }
    }
    getAppOptions() {
        return __awaiter(this, void 0, void 0, function* () {
            const { app = '' } = yield inquirer.prompt(createAppQuestions);
            create({
                createType: 'app',
                createName: this.appName,
                app
            });
        });
    }
    getPluginOptions() {
        return __awaiter(this, void 0, void 0, function* () {
            const { plugin } = yield inquirer.prompt(createPluginQuestions);
            create({
                createType: 'plugin',
                plugin
            });
        });
    }
}
export default CookieCli;
