import { AnyOptions } from '../types/index.js';
export declare const hasProperty: (target: AnyOptions, key: string) => any;
export declare const checkCurrentNodeVersion: (wanted: string) => void;
export declare const getPackageInfo: () => AnyOptions;
/**
 * @description 安装依赖包
 * @param {dependencies} 依赖
 * @param {isDev} 是否为开发依赖
 * @param {cwd} 安装路径
 * @date 2021-05-03 21:17:48
 */
export declare const installPackages: ({ dependencies, isDev, cwd, stdio }: {
    dependencies: string[];
    isDev: boolean;
    cwd: string;
    stdio?: 'inherit' | 'ignore';
}) => Promise<void>;
/**
 * @description 删除包
 * @date 2021-05-04 11:07:36
 */
export declare const removePackages: ({ dependencies, cwd, stdio }: {
    dependencies: string[];
    cwd: string;
    stdio?: 'inherit' | 'ignore';
}) => Promise<void>;
export declare const canUsePnpm: () => Promise<boolean>;
export declare const canUseYarn: () => Promise<boolean>;
export declare const canUseNpm: () => Promise<boolean>;
/**
 * @description 检查是否能用yarn or npm or pnpm
 * @param {*} async
 * @date 2021-05-04 11:18:52
 * @see
 * @return {*}
 */
export declare const checkPackageTools: () => Promise<{
    usePnpm: boolean;
    useYarn: boolean;
    useNpm: boolean;
    allPassed: boolean;
}>;
/**
 * @description 包初始化 执行命令为 npm init -y or yarn init -y
 * @param {cwd} 执行路径
 * @date 2021-05-04 22:10:27
 */
export declare const packageInit: (cwd?: string) => Promise<boolean>;
/**
 * @description 检查文件是否存在
 * @param {string} files
 * @param {string} cwd
 * @return {string} filename
 * @date 2021-06-14 16:47:04
 */
export declare const checkFileIfExists: (files: string[], cwd?: string) => string;
/**
 * @description 检查路径是否存在(文件夹)
 * @param {string} filePath
 * @param {*} canDelete 能否被删除
 * @date 2022-04-23 14:36:01
 * @return {Boolean}
 */
export declare const filePathExist: (filePath: string, canDelete?: boolean) => Promise<boolean>;
/**
 * @description 复制文件
 * @date 2022-11-13 16:03:27
 */
export declare const copyFile: (source: string, dest: string) => void;
/**
 * @description 读json文件
 * @param {string} jsonFilePath
 * @date 2022-10-11 16:30:18
 * @return {*} 返回解析后的json格式
 */
export declare const readJson: (jsonFilePath: string) => any;
/**
 * @description 将对象输出为json文件
 * @param {string} writePath
 * @param {any} writeData
 * @date 2022-10-11 16:34:49
 * @return {*}
 */
export declare const writeJson: ({ writePath, writeData, cover }: {
    writePath: string;
    writeData: AnyOptions;
    cover?: boolean;
}) => void;
/**
 * @description 根据key值合并对象
 * @param {*} originObj
 * @param {*} targetObj
 * @param {*} mergeKeys
 * @date 2022-11-13 15:41:51
 * @return {AnyOptions}
 */
export declare const mergeObject: ({ originObj, targetObj, mergeKeys }: {
    originObj: any;
    targetObj: any;
    mergeKeys?: any[];
}) => any;
